@@ -50,7 +50,7 @@ impl From<chrono::OutOfRangeError> for ClientError {
     }
 }
 
-/// The [`AuditorClientBuilder`] is used to build an instance of
+/// The `AuditorClientBuilder` is used to build an instance of
 /// either [`AuditorClient`] or [`AuditorClientBlocking`].
 ///
 /// # Examples
@@ -58,22 +58,28 @@ impl From<chrono::OutOfRangeError> for ClientError {
 /// Using the `address` and `port` of the Auditor instance:
 ///
 /// ```
-/// # use auditor::client::AuditorClientBuilder;
+/// # use auditor::client::{AuditorClientBuilder, ClientError};
 /// #
+/// # fn main() -> Result<(), ClientError> {
 /// let client = AuditorClientBuilder::new()
 ///     .address(&"localhost", 8000)
 ///     .timeout(20)
-///     .build();
+///     .build()?;
+/// # Ok(())
+/// # }
 /// ```
 ///
 /// Using an connection string:
 ///
 /// ```
-/// # use auditor::client::AuditorClientBuilder;
+/// # use auditor::client::{AuditorClientBuilder, ClientError};
 /// #
+/// # fn main() -> Result<(), ClientError> {
 /// let client = AuditorClientBuilder::new()
 ///     .connection_string(&"http://localhost:8000")
-///     .build();
+///     .build()?;
+/// # Ok(())
+/// # }
 /// ```
 #[derive(Clone)]
 pub struct AuditorClientBuilder {
@@ -85,7 +91,7 @@ impl AuditorClientBuilder {
     /// Constructor.
     pub fn new() -> AuditorClientBuilder {
         AuditorClientBuilder {
-            address: "127.0.0.1:8080".into(),
+            address: "http://127.0.0.1:8080".into(),
             timeout: Duration::seconds(30),
         }
     }
@@ -124,7 +130,7 @@ impl AuditorClientBuilder {
         self
     }
 
-    /// Build an [`AuditorClient`] from [`AuditorClientBuilder`].
+    /// Build an [`AuditorClient`] from `AuditorClientBuilder`.
     ///
     /// # Errors
     ///
@@ -140,7 +146,7 @@ impl AuditorClientBuilder {
         })
     }
 
-    /// Build an [`AuditorClientBlocking`] from [`AuditorClientBuilder`].
+    /// Build an [`AuditorClientBlocking`] from `AuditorClientBuilder`.
     ///
     /// # Errors
     ///
@@ -167,9 +173,11 @@ impl Default for AuditorClientBuilder {
     }
 }
 
-/// The [`AuditorClient`] handles the interaction with the Auditor instances and allows one to add
+/// The `AuditorClient` handles the interaction with the Auditor instances and allows one to add
 /// records to the database, update records in the database and retrieve the records from the
 /// database.
+///
+/// It is constructed using the [`AuditorClientBuilder`].
 #[derive(Clone)]
 pub struct AuditorClient {
     address: String,
@@ -186,7 +194,7 @@ impl AuditorClient {
             .send()
             .await
         {
-            Ok(s) => matches!(s.error_for_status(), Ok(_)),
+            Ok(s) => s.error_for_status().is_ok(),
             Err(_) => false,
         }
     }
@@ -314,9 +322,11 @@ impl AuditorClient {
     }
 }
 
-/// The [`AuditorClientBlocking`] handles the interaction with the Auditor instances and allows one to add
+/// The `AuditorClientBlocking` handles the interaction with the Auditor instances and allows one to add
 /// records to the database, update records in the database and retrieve the records from the
 /// database. In contrast to [`AuditorClient`], no async runtime is needed here.
+///
+/// It is constructed using the [`AuditorClientBuilder`].
 #[derive(Clone)]
 pub struct AuditorClientBlocking {
     address: String,
@@ -332,7 +342,7 @@ impl AuditorClientBlocking {
             .get(format!("{}/health_check", &self.address))
             .send()
         {
-            Ok(s) => matches!(s.error_for_status(), Ok(_)),
+            Ok(s) => s.error_for_status().is_ok(),
             Err(_) => false,
         }
     }
@@ -484,7 +494,7 @@ mod tests {
 
         response
             .into_iter()
-            .zip(body.into_iter())
+            .zip(body)
             .map(|(rr, br)| assert_eq!(rr, br))
             .count();
     }
@@ -517,7 +527,7 @@ mod tests {
 
         response
             .into_iter()
-            .zip(body.into_iter())
+            .zip(body)
             .map(|(rr, br)| assert_eq!(rr, br))
             .count();
     }
@@ -883,7 +893,7 @@ mod tests {
 
         response
             .into_iter()
-            .zip(body.into_iter())
+            .zip(body)
             .map(|(rr, br)| assert_eq!(rr, br))
             .count();
     }
@@ -919,7 +929,7 @@ mod tests {
 
         response
             .into_iter()
-            .zip(body.into_iter())
+            .zip(body)
             .map(|(rr, br)| assert_eq!(rr, br))
             .count();
     }
@@ -997,7 +1007,7 @@ mod tests {
 
         response
             .into_iter()
-            .zip(body.into_iter())
+            .zip(body)
             .map(|(rr, br)| assert_eq!(rr, br))
             .count();
     }
@@ -1033,7 +1043,7 @@ mod tests {
 
         response
             .into_iter()
-            .zip(body.into_iter())
+            .zip(body)
             .map(|(rr, br)| assert_eq!(rr, br))
             .count();
     }
