@@ -3,7 +3,6 @@
 import asyncio
 from pyauditor import AuditorClientBuilder, Record
 import datetime
-import pytz
 from tzlocal import get_localzone
 
 
@@ -27,11 +26,9 @@ async def main():
         record_id = f"record-{i:02d}"
 
         # datetimes sent to auditor MUST BE in UTC.
-        start = datetime.datetime(2022, 8, 8, i, 0, 0, 0, tzinfo=pytz.utc)
-        stop = datetime.datetime(2022, 8, 9, i, 0, 0, 0, tzinfo=pytz.utc)
-        record = Record(record_id, start).with_stop_time(
-            stop
-        )
+        start = datetime.datetime(2022, 8, 8, i, 0, 0, 0, tzinfo=datetime.timezone.utc)
+        stop = datetime.datetime(2022, 8, 9, i, 0, 0, 0, tzinfo=datetime.timezone.utc)
+        record = Record(record_id, start).with_stop_time(stop)
 
         await client.add(record)
 
@@ -45,7 +42,9 @@ async def main():
     for i in range(0, 24):
         assert records[i].record_id == f"record-{i:02d}"
 
-    start_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=pytz.utc)
+    start_since = datetime.datetime(
+        2022, 8, 8, 11, 30, 0, 0, tzinfo=datetime.timezone.utc
+    )
 
     records = await client.get_started_since(start_since)
     assert len(records) == 12
@@ -55,7 +54,9 @@ async def main():
     for i in range(12, 24):
         assert records[i - 12].record_id == f"record-{i:02d}"
 
-    stop_since = datetime.datetime(2022, 8, 9, 11, 30, 0, 0, tzinfo=pytz.utc)
+    stop_since = datetime.datetime(
+        2022, 8, 9, 11, 30, 0, 0, tzinfo=datetime.timezone.utc
+    )
 
     records = await client.get_stopped_since(stop_since)
     assert len(records) == 12
